# This file was auto-generated by Fern from our API Definition.

import typing

ExtractRequestConfigChunkingMethod = typing.Union[typing.Literal["none", "sentence", "paragraph", "topics"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .extract_request_config_chunking_method import ExtractRequestConfigChunkingMethod


class ExtractRequestConfig(UniversalBaseModel):
    chunking_method: typing.Optional[ExtractRequestConfigChunkingMethod] = None
    max_codes_per_chunk: typing.Optional[int] = None
    code_similarity_filter: typing.Optional[float] = None
    include_rationale: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .construe_cohort_response_queries_item_code_extract_results_item import (
    ConstrueCohortResponseQueriesItemCodeExtractResultsItem,
)


class ConstrueCohortResponseQueriesItem(UniversalBaseModel):
    resource: typing.Optional[str] = pydantic.Field(default=None)
    """
    FHIR resource type (e.g., "Patient", "Condition").
    """

    search_params: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="searchParams")] = (
        pydantic.Field(default=None)
    )
    """
    FHIR search parameters.
    """

    exclude: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates if this is an exclusion criteria.
    """

    rationale: typing.Optional[str] = pydantic.Field(default=None)
    """
    AI-generated explanation for the query component.
    """

    code_extract_results: typing_extensions.Annotated[
        typing.Optional[typing.List[ConstrueCohortResponseQueriesItemCodeExtractResultsItem]],
        FieldMetadata(alias="codeExtractResults"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .construe_cohort_response_queries_item import ConstrueCohortResponseQueriesItem


class ConstrueCohortResponse(UniversalBaseModel):
    queries: typing.Optional[typing.List[ConstrueCohortResponseQueriesItem]] = None
    sql: typing.Optional[str] = pydantic.Field(default=None)
    """
    Generated SQL query when `sql_syntax` is specified. Variables in curly braces need to be replaced with your actual table names.
    """

    cohort_description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="cohortDescription")] = (
        pydantic.Field(default=None)
    )
    """
    Echo of the input text description for reference.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .construe_cohort_response_queries_item_code_extract_results_item_codes_item import (
    ConstrueCohortResponseQueriesItemCodeExtractResultsItemCodesItem,
)


class ConstrueCohortResponseQueriesItemCodeExtractResultsItem(UniversalBaseModel):
    system_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="systemName")] = pydantic.Field(
        default=None
    )
    """
    Name of the coding system (e.g., "SNOMED_CT_US_LITE").
    """

    codes: typing.Optional[typing.List[ConstrueCohortResponseQueriesItemCodeExtractResultsItemCodesItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ConstrueCohortRequestConfig(UniversalBaseModel):
    include_extract_results: typing.Optional[bool] = pydantic.Field(default=None)
    """
    When enabled, includes detailed information about medical codes extracted from the text.
    """

    include_rationale: typing.Optional[bool] = pydantic.Field(default=None)
    """
    When enabled, includes AI-generated explanations for each query component and code extraction.
    """

    exclude_deceased: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Controls whether deceased patients should be excluded from the cohort.
    """

    sql_syntax: typing.Optional[typing.Literal["bigquery"]] = pydantic.Field(default=None)
    """
    Specifies the SQL dialect for query generation. Currently, only "bigquery" is supported.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .bad_request_error_body import BadRequestErrorBody
from .construe_cohort_request_config import ConstrueCohortRequestConfig
from .construe_cohort_response import ConstrueCohortResponse
from .construe_cohort_response_queries_item import ConstrueCohortResponseQueriesItem
from .construe_cohort_response_queries_item_code_extract_results_item import (
    ConstrueCohortResponseQueriesItemCodeExtractResultsItem,
)
from .construe_cohort_response_queries_item_code_extract_results_item_codes_item import (
    ConstrueCohortResponseQueriesItemCodeExtractResultsItemCodesItem,
)
from .construe_upload_code_system_response import ConstrueUploadCodeSystemResponse
from .extract_codes_result import ExtractCodesResult
from .extract_request_config import ExtractRequestConfig
from .extract_request_config_chunking_method import ExtractRequestConfigChunkingMethod
from .extract_request_system import ExtractRequestSystem
from .extracted_code_result import ExtractedCodeResult
from .internal_server_error_body import InternalServerErrorBody
from .unauthorized_error_body import UnauthorizedErrorBody
from .upload_request_format import UploadRequestFormat

__all__ = [
    "BadRequestErrorBody",
    "ConstrueCohortRequestConfig",
    "ConstrueCohortResponse",
    "ConstrueCohortResponseQueriesItem",
    "ConstrueCohortResponseQueriesItemCodeExtractResultsItem",
    "ConstrueCohortResponseQueriesItemCodeExtractResultsItemCodesItem",
    "ConstrueUploadCodeSystemResponse",
    "ExtractCodesResult",
    "ExtractRequestConfig",
    "ExtractRequestConfigChunkingMethod",
    "ExtractRequestSystem",
    "ExtractedCodeResult",
    "InternalServerErrorBody",
    "UnauthorizedErrorBody",
    "UploadRequestFormat",
]
